@@ -195,7 +195,7 @@ def _merge_index(
 
 
 def _get_file_system(path: str) -> fsspec.AbstractFileSystem:
-    return fsspec.core.url_to_fs(path, use_listings_cache=False)[0]
+    return fsspec.core.url_to_fs(path)[0]
 
 
 def _merge_to_n_indices(spark_session, n: int, src_folder: str):
@@ -268,8 +268,9 @@ def run(
     n_workers = len(sc.statusTracker().getExecutorInfos()) - 1
 
     # maximum between the number of spark workers, 100M embeddings per task and the number of indices to keep
-    nb_batches = max(n_workers, int(embedding_reader.count / (10 ** 7)), nb_indices_to_keep)
-    batch_size = math.ceil(embedding_reader.count / nb_batches)
+    estimated_nb_batches = max(n_workers, int(embedding_reader.count / (10 ** 7)), nb_indices_to_keep)
+    batch_size = math.ceil(embedding_reader.count / estimated_nb_batches)
+    nb_batches = math.ceil(embedding_reader.count / batch_size)
 
     batches = _batch_loader(batch_size=batch_size, nb_batches=nb_batches)
     rdd = ss.sparkContext.parallelize(batches, nb_batches)
