@@ -1,7 +1,7 @@
 # pylint: disable=all
 
-__version__ = "2.11.2"
-__author__ = "rom1504"
+__version__ = "2.12.0"
+__author__ = "Criteo"
 
 
 MAJOR = __version__.split(".")[0]
